#[repr(transparent)]pub struct Tempsense0(pub u32);Expand description
Tempsensor Control Register 0
Tuple Fields
0: u32Implementations
Sourceimpl Tempsense0
impl Tempsense0
Sourcepub const fn power_down(&self) -> Tempsense0PowerDown
pub const fn power_down(&self) -> Tempsense0PowerDown
This bit powers down the temperature sensor.
Sourcepub const fn set_power_down(&mut self, val: Tempsense0PowerDown)
pub const fn set_power_down(&mut self, val: Tempsense0PowerDown)
This bit powers down the temperature sensor.
Sourcepub const fn measure_temp(&self) -> Tempsense0MeasureTemp
pub const fn measure_temp(&self) -> Tempsense0MeasureTemp
Starts the measurement process
Sourcepub const fn set_measure_temp(&mut self, val: Tempsense0MeasureTemp)
pub const fn set_measure_temp(&mut self, val: Tempsense0MeasureTemp)
Starts the measurement process
Sourcepub const fn set_finished(&mut self, val: bool)
pub const fn set_finished(&mut self, val: bool)
Indicates that the latest temp is valid
Sourcepub const fn temp_cnt(&self) -> u16
pub const fn temp_cnt(&self) -> u16
This bit field contains the last measured temperature count.
Sourcepub const fn set_temp_cnt(&mut self, val: u16)
pub const fn set_temp_cnt(&mut self, val: u16)
This bit field contains the last measured temperature count.
Sourcepub const fn alarm_value(&self) -> u16
pub const fn alarm_value(&self) -> u16
This bit field contains the temperature count (raw sensor output) that will generate a high alarm when TEMP_CNT is smaller than this field
Sourcepub const fn set_alarm_value(&mut self, val: u16)
pub const fn set_alarm_value(&mut self, val: u16)
This bit field contains the temperature count (raw sensor output) that will generate a high alarm when TEMP_CNT is smaller than this field