nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Tempsense0Tog

Struct Tempsense0Tog 

#[repr(transparent)]
pub struct Tempsense0Tog(pub u32);
Tempsensor Control Register 0

Tuple Fields

0: u32

Implementations

Source

impl Tempsense0Tog

pub const fn power_down(&self) -> Tempsense0TogPowerDown

This bit powers down the temperature sensor.

pub const fn set_power_down(&mut self, val: Tempsense0TogPowerDown)

This bit powers down the temperature sensor.

pub const fn measure_temp(&self) -> Tempsense0TogMeasureTemp

Starts the measurement process

pub const fn set_measure_temp(&mut self, val: Tempsense0TogMeasureTemp)

Starts the measurement process

pub const fn finished(&self) -> bool

Indicates that the latest temp is valid

pub const fn set_finished(&mut self, val: bool)

Indicates that the latest temp is valid

pub const fn temp_cnt(&self) -> u16

This bit field contains the last measured temperature count.

pub const fn set_temp_cnt(&mut self, val: u16)

This bit field contains the last measured temperature count.

pub const fn alarm_value(&self) -> u16

This bit field contains the temperature count (raw sensor output) that will generate a high alarm when TEMP_CNT is smaller than this field

pub const fn set_alarm_value(&mut self, val: u16)

This bit field contains the temperature count (raw sensor output) that will generate a high alarm when TEMP_CNT is smaller than this field