#[repr(transparent)]pub struct Tempsense2Set(pub u32);Expand description
Tempsensor Control Register 2
Tuple Fields
0: u32Implementations
Sourceimpl Tempsense2Set
impl Tempsense2Set
Sourcepub const fn low_alarm_value(&self) -> u16
pub const fn low_alarm_value(&self) -> u16
This bit field contains the temperature count that will generate a low alarm interrupt when the field is exceeded by TEMP_CNT
Sourcepub const fn set_low_alarm_value(&mut self, val: u16)
pub const fn set_low_alarm_value(&mut self, val: u16)
This bit field contains the temperature count that will generate a low alarm interrupt when the field is exceeded by TEMP_CNT
Sourcepub const fn panic_alarm_value(&self) -> u16
pub const fn panic_alarm_value(&self) -> u16
This bit field contains the temperature count that will generate a panic interrupt when TEMP_CNT is smaller than this field
Sourcepub const fn set_panic_alarm_value(&mut self, val: u16)
pub const fn set_panic_alarm_value(&mut self, val: u16)
This bit field contains the temperature count that will generate a panic interrupt when TEMP_CNT is smaller than this field